@@ -1,4 +1,4 @@
-/* global setUserSetting, ajaxurl, commonL10n, alert, confirm, toggleWithKeyboard, pagenow */
+/* global setUserSetting, ajaxurl, commonL10n, alert, confirm, pagenow */
 var showNotice, adminMenu, columns, validateForm, screenMeta;
 ( function( $, window, undefined ) {
 // Removed in 3.3.
@@ -228,7 +228,10 @@ $(document).ready( function() {
 		});
 
 		menu.find('a.wp-has-submenu').on( mobileEvent+'.wp-mobile-hover', function(e) {
-			var el = $(this), parent = el.parent();
+			var b, h, o, f, menutop, wintop, maxtop,
+				el = $(this),
+				parent = el.parent(),
+				m = parent.find('.wp-submenu');
 
 			if ( menu.data('wp-responsive') ) {
 				return;
@@ -239,6 +242,30 @@ $(document).ready( function() {
 			//	- the submenu is not shown inline or the menu is not folded
 			if ( !parent.hasClass('opensub') && ( !parent.hasClass('wp-menu-open') || parent.width() < 40 ) ) {
 				e.preventDefault();
+
+				menutop = parent.offset().top;
+				wintop = $(window).scrollTop();
+				maxtop = menutop - wintop - 30; // max = make the top of the sub almost touch admin bar
+
+				b = menutop + m.height() + 1; // Bottom offset of the menu
+				h = $('#wpwrap').height(); // Height of the entire page
+				o = 60 + b - h;
+				f = $(window).height() + wintop - 50; // The fold
+
+				if ( f < (b - o) ) {
+					o = b - f;
+				}
+
+				if ( o > maxtop ) {
+					o = maxtop;
+				}
+
+				if ( o > 1 ) {
+					m.css('margin-top', '-'+o+'px');
+				} else {
+					m.css('margin-top', '');
+				}
+
 				menu.find('li.opensub').removeClass('opensub');
 				parent.addClass('opensub');
 			}
@@ -249,8 +276,9 @@ $(document).ready( function() {
 		over: function() {
 			var b, h, o, f, m = $(this).find('.wp-submenu'), menutop, wintop, maxtop, top = parseInt( m.css('top'), 10 );
 
-			if ( isNaN(top) || top > -5 ) // meaning the submenu is visible
+			if ( isNaN(top) || top > -5 ) { // meaning the submenu is visible
 				return;
+			}
 
 			if ( menu.data('wp-responsive') ) {
 				// The menu is in responsive mode, bail
@@ -266,16 +294,19 @@ $(document).ready( function() {
 			o = 60 + b - h;
 			f = $(window).height() + wintop - 15; // The fold
 
-			if ( f < (b - o) )
+			if ( f < (b - o) ) {
 				o = b - f;
+			}
 
-			if ( o > maxtop )
+			if ( o > maxtop ) {
 				o = maxtop;
+			}
 
-			if ( o > 1 )
+			if ( o > 1 ) {
 				m.css('margin-top', '-'+o+'px');
-			else
+			} else {
 				m.css('margin-top', '');
+			}
 
 			menu.find('li.menu-top').removeClass('opensub');
 			$(this).addClass('opensub');
@@ -346,32 +377,39 @@ $(document).ready( function() {
 		return true;
 	});
 
-	$('thead, tfoot').find('.check-column :checkbox').click( function(e) {
-		var c = $(this).prop('checked'),
-			kbtoggle = 'undefined' == typeof toggleWithKeyboard ? false : toggleWithKeyboard,
-			toggle = e.shiftKey || kbtoggle;
+	$('thead, tfoot').find('.check-column :checkbox').on( 'click.wp-toggle-checkboxes', function( event ) {
+		var $this = $(this),
+			$table = $this.closest( 'table' ),
+			controlChecked = $this.prop('checked'),
+			toggle = event.shiftKey || $this.data('wp-toggle');
 
-		$(this).closest( 'table' ).children( 'tbody' ).filter(':visible')
-		.children().children('.check-column').find(':checkbox')
-		.prop('checked', function() {
-			if ( $(this).is(':hidden') )
-				return false;
-			if ( toggle )
-				return $(this).prop( 'checked' );
-			else if (c)
-				return true;
-			return false;
-		});
+		$table.children( 'tbody' ).filter(':visible')
+			.children().children('.check-column').find(':checkbox')
+			.prop('checked', function() {
+				if ( $(this).is(':hidden') ) {
+					return false;
+				}
+
+				if ( toggle ) {
+					return ! $(this).prop( 'checked' );
+				} else if ( controlChecked ) {
+					return true;
+				}
 
-		$(this).closest('table').children('thead,  tfoot').filter(':visible')
-		.children().children('.check-column').find(':checkbox')
-		.prop('checked', function() {
-			if ( toggle )
 				return false;
-			else if (c)
-				return true;
-			return false;
-		});
+			});
+
+		$table.children('thead,  tfoot').filter(':visible')
+			.children().children('.check-column').find(':checkbox')
+			.prop('checked', function() {
+				if ( toggle ) {
+					return false;
+				} else if ( controlChecked ) {
+					return true;
+				}
+
+				return false;
+			});
 	});
 
 	// Show row actions on keyboard focus of its parent container element or any other elements contained within
@@ -694,15 +732,4 @@ $(document).ready( function() {
 	}
 })();
 
-// internal use
-$(document).bind( 'wp_CloseOnEscape', function( e, data ) {
-	if ( typeof(data.cb) != 'function' )
-		return;
-
-	if ( typeof(data.condition) != 'function' || data.condition() )
-		data.cb();
-
-	return true;
-});
-
 }( jQuery, window ));
